@@ -3,6 +3,7 @@ from dataclasses import dataclass
 from typing import Annotated, Any, Literal
 
 from google.protobuf import json_format
+from mashumaro.config import BaseConfig
 from mashumaro.mixins.orjson import DataClassORJSONMixin
 from mashumaro.types import Alias, SerializableType
 
@@ -103,6 +104,9 @@ class GeneralParams(DataClassORJSONMixin):
     device_type: Annotated[str | None, Alias("deviceType")] = None
     _trace_id: Annotated[str | None, Alias("_traceId")] = None
 
+    class Config(BaseConfig):
+        allow_deserialization_not_by_alias = True
+
 
 @dataclass
 class DeviceProtobufMsgEventParams(GeneralParams):
