@@ -2,6 +2,7 @@ from dataclasses import dataclass
 from typing import Annotated, Any, Literal, Union
 
 from mashumaro import DataClassDictMixin
+from mashumaro.config import BaseConfig
 from mashumaro.mixins.orjson import DataClassORJSONMixin
 from mashumaro.types import Alias
 
@@ -182,6 +183,9 @@ class Params(DataClassORJSONMixin):
     items: Annotated["Items", Alias("items")]
     tenant_instance_id: Annotated[str, Alias("tenantInstanceId")]
 
+    class Config(BaseConfig):
+        allow_deserialization_not_by_alias = True
+
 
 @dataclass
 class ThingPropertiesMessage(DataClassORJSONMixin):
