@@ -107,6 +107,13 @@ class MammotionDeviceManager:
         """Get a mower device."""
         return self.devices[mammotion_device_name]
 
+    def get_device_by_iot_id(self, iot_id: str) -> MammotionMowerDeviceManager | None:
+        """Get a mower device by IoT ID."""
+        for device in self.devices.values():
+            if device.iot_id == iot_id:
+                return device
+        return None
+
     def get_rtk_device(self, rtk_device_name: str) -> MammotionRTKDeviceManager:
         """Get an RTK device."""
         return self.rtk_devices[rtk_device_name]
@@ -162,7 +169,7 @@ class Mammotion:
         self._login_lock = asyncio.Lock()
         self.mqtt_list: dict[str, MammotionCloud] = {}
 
-    async def login_and_initiate_cloud(self, account, password, force: bool = False) -> None:
+    async def login_and_initiate_cloud(self, account: str, password: str, force: bool = False) -> None:
         async with self._login_lock:
             exists_aliyun: MammotionCloud | None = self.mqtt_list.get(f"{account}_aliyun")
             exists_mammotion: MammotionCloud | None = self.mqtt_list.get(f"{account}_mammotion")
