@@ -1,5 +1,6 @@
 """Package for MammotionMQTT."""
 
+from .aliyun_mqtt import AliyunMQTT
 from .mammotion_mqtt import MammotionMQTT
 
-__all__ = ["MammotionMQTT"]
+__all__ = ["AliyunMQTT", "MammotionMQTT"]
